@@ -18,4 +18,6 @@
 # For a full list of contributors, please see the AUTHORS.md file.
 """BLITSkrieg package."""
 
-__version__ = "0.1.0"
+import importlib.metadata
+
+__version__ = importlib.metadata.version('blitskrieg')
